package com.qianhe.mapper;

import com.qianhe.domain.BzscYsjglggzscCb;

import java.util.List;

/**
 * 标准手册-油水井管理岗工作手册-从Mapper接口
 *
 * @author qianhe
 * @date 2024-10-09
 */
public interface BzscYsjglggzscCbMapper
{
    /**
     * 查询标准手册-油水井管理岗工作手册-从
     *
     * @param ID 标准手册-油水井管理岗工作手册-从主键
     * @return 标准手册-油水井管理岗工作手册-从
     */
    public BzscYsjglggzscCb selectBzscYsjglggzscCbByID(Long ID);

    /**
     * 查询标准手册-油水井管理岗工作手册-从列表
     *
     * @param bzscYsjglggzscCb 标准手册-油水井管理岗工作手册-从
     * @return 标准手册-油水井管理岗工作手册-从集合
     */
    public List<BzscYsjglggzscCb> selectBzscYsjglggzscCbList(BzscYsjglggzscCb bzscYsjglggzscCb);

    /**
     * 新增标准手册-油水井管理岗工作手册-从
     *
     * @param bzscYsjglggzscCb 标准手册-油水井管理岗工作手册-从
     * @return 结果
     */
    public int insertBzscYsjglggzscCb(BzscYsjglggzscCb bzscYsjglggzscCb);

    /**
     * 修改标准手册-油水井管理岗工作手册-从
     *
     * @param bzscYsjglggzscCb 标准手册-油水井管理岗工作手册-从
     * @return 结果
     */
    public int updateBzscYsjglggzscCb(BzscYsjglggzscCb bzscYsjglggzscCb);

    /**
     * 删除标准手册-油水井管理岗工作手册-从
     *
     * @param ID 标准手册-油水井管理岗工作手册-从主键
     * @return 结果
     */
    public int deleteBzscYsjglggzscCbByID(Long ID);

    /**
     * 批量删除标准手册-油水井管理岗工作手册-从
     *
     * @param IDs 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBzscYsjglggzscCbByIDs(Long[] IDs);
}
